diff --git a/pysollib/customgame.py b/pysollib/customgame.py
index 9adc968d..8bc408ff 100644
--- a/pysollib/customgame.py
+++ b/pysollib/customgame.py
@@ -129,7 +129,7 @@ class CustomGame(Game):
         layout_kw['playcards'] = max(16, playcards)
         if s['talon'] in (DealRowRedealTalonStack,
                           SpiderTalonStack,
-                          GroundForADivorceTalonStack):
+                          GroundsForADivorceTalonStack):
             layout_kw['playcards'] += 2 * s['decks']
 
         # reserves
diff --git a/pysollib/gamedb.py b/pysollib/gamedb.py
index 0d32a8a6..5e46a579 100644
--- a/pysollib/gamedb.py
+++ b/pysollib/gamedb.py
@@ -353,13 +353,14 @@ class GI:
                       16674, 16675, 16676, 16677, 16678, 16679, 16680, 22216,
                       22223, 22224, 22225, 22226, 22227, 22228, 22229, 22230,
                       22231, 22232,)),
-        ('fc-0.8.0', tuple(range(263, 323))),
+        ('fc-0.8.0', tuple(range(263, 323))), # exclude 297
         ('fc-0.9.0', tuple(range(323, 421))),
         ('fc-0.9.1', tuple(range(421, 441))),
         ('fc-0.9.2', tuple(range(441, 466))),
         ('fc-0.9.3', tuple(range(466, 661))),
         ('fc-0.9.4', tuple(range(661, 671))),
         ('fc-1.0',   tuple(range(671, 711))),
+        ('fc-1.1',   tuple(range(711, 756))),
     )
 
     # deprecated - the correct way is to or a GI.GT_XXX flag
@@ -377,7 +378,7 @@ class GI:
         11,    # Spider
         12,    # Braid
         13,    # Forty Thieves
-        14,    # Ground for a Divorce
+        14,    # Grounds for a Divorce
         19,    # Yukon
         31,    # Baker's Dozen
         36,    # Golf
diff --git a/pysollib/settings.py b/pysollib/settings.py
index 7322765f..194cf1ac 100644
--- a/pysollib/settings.py
+++ b/pysollib/settings.py
@@ -26,11 +26,10 @@ n_ = lambda x: x                        # for gettext
 
 PACKAGE = 'PySolFC'
 TITLE = 'PySol'
-#PACKAGE_URL = 'http://pysolfc.sourceforge.net/'
-PACKAGE_URL = 'http://sourceforge.net/projects/pysolfc/'
+PACKAGE_URL = 'http://pysolfc.sourceforge.net/'
 
-VERSION = '1.0.1'
-VERSION_TUPLE = (1, 0, 1)
+VERSION = '1.1'
+VERSION_TUPLE = (1, 1)
 
 # Tk windowing system (auto set up in init.py)
 WIN_SYSTEM = 'x11'                      # win32, x11, aqua, classic
diff --git a/pysollib/stack.py b/pysollib/stack.py
index 3c12218c..eee6ce61 100644
--- a/pysollib/stack.py
+++ b/pysollib/stack.py
@@ -53,7 +53,7 @@ __all__ = ['cardsFaceUp',
            'DealRowRedealTalonStack',
            'DealReserveRedealTalonStack',
            'SpiderTalonStack',
-           'GroundForADivorceTalonStack',
+           'GroundsForADivorceTalonStack',
            'OpenStack',
            'AbstractFoundationStack',
            'SS_FoundationStack',
@@ -1942,7 +1942,7 @@ class SpiderTalonStack(DealRowRedealTalonStack):
                 return False
         return True
 
-class GroundForADivorceTalonStack(DealRowRedealTalonStack):
+class GroundsForADivorceTalonStack(DealRowRedealTalonStack):
     # A single click deals a new cards to each non-empty row.
     def dealCards(self, sound=True):
         if self.cards:
diff --git a/pysollib/tile/toolbar.py b/pysollib/tile/toolbar.py
index 917dd418..f257f74a 100644
--- a/pysollib/tile/toolbar.py
+++ b/pysollib/tile/toolbar.py
@@ -295,7 +295,7 @@ class PysolToolbar(PysolToolbarActions):
     def _setButtonImage(self, button, name):
         image = self._loadImage(name)
         setattr(self, name + "_image", image)
-        if Image: # XXX: and WIN_SYSTEM != 'aqua':
+        if Image:
             dis_image = self._createDisabledButtonImage(image)
             if dis_image:
                 setattr(self, name + "_disabled_image", dis_image)
diff --git a/pysollib/wizardpresets.py b/pysollib/wizardpresets.py
index 65a25727..260d26fb 100644
--- a/pysollib/wizardpresets.py
+++ b/pysollib/wizardpresets.py
@@ -78,13 +78,13 @@ presets = {
         'deal_face_up': 1,
         },
 
-    'Ground for a Divorce': {
-        'preset': 'Ground for a Divorce',
-        'name': n_('My Ground for a Divorce'),
+    'Grounds for a Divorce': {
+        'preset': 'Grounds for a Divorce',
+        'name': n_('My Grounds for a Divorce'),
         'skill_level': 'Mostly skill',
         'decks': 'Two',
         'layout': 'Harp',
-        'talon': 'Ground for a Divorce',
+        'talon': 'Grounds for a Divorce',
         'found_type': 'Spider same suit',
         'found_base_card': 'Any',
         'found_equal': 0,
diff --git a/pysollib/wizardutil.py b/pysollib/wizardutil.py
index f6e452c2..b5def548 100644
--- a/pysollib/wizardutil.py
+++ b/pysollib/wizardutil.py
@@ -105,14 +105,14 @@ LayoutType = WizSetting(
     var_name = 'layout',
     )
 TalonType = WizSetting(
-    values_map = ((n_('Initial dealing'),      InitialDealTalonStack),
-                  (n_('Deal to waste'),        WasteTalonStack),
-                  (n_('Deal to tableau'),      DealRowRedealTalonStack),
-                  (n_('Deal to reserves'),     DealReserveRedealTalonStack),
-                  (n_('Spider'),               SpiderTalonStack),
-                  (n_('Ground for a Divorce'), GroundForADivorceTalonStack),
+    values_map = ((n_('Opening deal'),          InitialDealTalonStack),
+                  (n_('Deal to waste'),         WasteTalonStack),
+                  (n_('Deal to tableau'),       DealRowRedealTalonStack),
+                  (n_('Deal to reserves'),      DealReserveRedealTalonStack),
+                  (n_('Spider'),                SpiderTalonStack),
+                  (n_('Grounds for a Divorce'), GroundsForADivorceTalonStack),
                   ),
-    default = n_('Initial dealing'),
+    default = n_('Opening deal'),
     label = _('Type:'),
     var_name = 'talon',
     )
diff --git a/pysollib/games/spider.py b/pysollib/games/spider.py
index c693fb33..1ba5b236 100644
--- a/pysollib/games/spider.py
+++ b/pysollib/games/spider.py
@@ -181,10 +181,10 @@ class BlackWidow(Spider):
 
 
 # /***********************************************************************
 # // Scheidungsgrund (aka Ground for a Divorce)
 # ************************************************************************/
 
-class GroundForADivorce_Talon(TalonStack):
+class GroundsForADivorce_Talon(TalonStack):
     # A single click deals a new cards to each non-empty row.
     def dealCards(self, sound=True):
         if self.cards:
@@ -196,9 +196,9 @@ class GroundForADivorce_Talon(TalonStack):
         return 0
 
 
-class GroundForADivorce(RelaxedSpider):
+class GroundsForADivorce(RelaxedSpider):
     Layout_Method = Layout.harpLayout
-    Talon_Class = GroundForADivorce_Talon
+    Talon_Class = GroundsForADivorce_Talon
     Foundation_Class = StackWrapper(Spider_SS_Foundation, base_rank=ANY_RANK, mod=13)
     RowStack_Class = StackWrapper(Spider_RowStack, mod=13)
 
@@ -891,8 +891,8 @@ class Spider3x3(BigSpider):
         self.s.talon.dealRow()
 
 
-class GroundForADivorce3Decks(BigSpider):
-    Talon_Class = GroundForADivorce_Talon
+class GroundsForADivorce3Decks(BigSpider):
+    Talon_Class = GroundsForADivorce_Talon
     Foundation_Class = StackWrapper(Spider_SS_Foundation, base_rank=ANY_RANK, mod=13)
     RowStack_Class = StackWrapper(Spider_RowStack, mod=13)
     def canDealCards(self):
@@ -929,8 +929,8 @@ class Spider4Decks(BigSpider):
         l.defaultRegions()
 
 
-class GroundForADivorce4Decks(Spider4Decks):
-    Talon_Class = GroundForADivorce_Talon
+class GroundsForADivorce4Decks(Spider4Decks):
+    Talon_Class = GroundsForADivorce_Talon
     Foundation_Class = StackWrapper(Spider_SS_Foundation, base_rank=ANY_RANK, mod=13)
     RowStack_Class = StackWrapper(Spider_RowStack, mod=13)
     def createGame(self):
@@ -1089,7 +1089,7 @@ class ShortTail(LongTail):
 # ************************************************************************/
 
 class Incompatibility(Spidike):
-    Talon_Class = GroundForADivorce_Talon
+    Talon_Class = GroundsForADivorce_Talon
     RowStack_Class = Spider_SS_RowStack
 
     def createGame(self):
@@ -1364,7 +1364,7 @@ registerGame(GameInfo(11, Spider, "Spider",
 registerGame(GameInfo(49, BlackWidow, "Black Widow",
                       GI.GT_SPIDER, 2, 0, GI.SL_MOSTLY_SKILL,
                       altnames=("Scarab",) ))
-registerGame(GameInfo(14, GroundForADivorce, "Ground for a Divorce",
+registerGame(GameInfo(14, GroundsForADivorce, "Grounds for a Divorce",
                       GI.GT_SPIDER, 2, 0, GI.SL_MOSTLY_SKILL,
                       altnames=('Scheidungsgrund',) ))
 registerGame(GameInfo(114, GrandmothersGame, "Grandmother's Game",
@@ -1417,7 +1417,7 @@ registerGame(GameInfo(382, Applegate, "Applegate",
                       GI.GT_SPIDER, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(384, BigSpider, "Big Spider",
                       GI.GT_SPIDER, 3, 0, GI.SL_MOSTLY_SKILL))
-registerGame(GameInfo(401, GroundForADivorce3Decks, "Big Divorce",
+registerGame(GameInfo(401, GroundsForADivorce3Decks, "Big Divorce",
                       GI.GT_SPIDER, 3, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(441, York, "York",
                       GI.GT_SPIDER | GI.GT_OPEN | GI.GT_ORIGINAL, 2, 0, GI.SL_SKILL))
@@ -1437,7 +1437,7 @@ registerGame(GameInfo(449, Spider3x3, "Spider 3x3",
                       rules_filename="bigspider.html"))
 registerGame(GameInfo(454, Spider4Decks, "Spider (4 decks)",
                       GI.GT_SPIDER, 4, 0, GI.SL_MOSTLY_SKILL))
-registerGame(GameInfo(455, GroundForADivorce4Decks, "Very Big Divorce",
+registerGame(GameInfo(455, GroundsForADivorce4Decks, "Very Big Divorce",
                       GI.GT_SPIDER, 4, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(458, Spidike, "Spidike",
                       GI.GT_SPIDER, 1, 0, GI.SL_BALANCED)) # GT_GYPSY ?
@@ -181,10 +181,10 @@ class BlackWidow(Spider):
 
 # /***********************************************************************
-# // Scheidungsgrund (aka Ground for a Divorce)
+# // Scheidungsgrund (aka Grounds for a Divorce)
 # ************************************************************************/
 